==> haskell-aeson-pretty-0.8.10-134-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-pretty
version:              0.8.10
visibility:           public
id:                   aeson-pretty-0.8.10-HGqdLPRnyeEEY0lM8KqhKG
key:                  aeson-pretty-0.8.10-HGqdLPRnyeEEY0lM8KqhKG
license:              BSD-3-Clause
copyright:            Copyright 2011 Falko Peters
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Falko Peters <falko.peters@gmail.com>
stability:            experimental
homepage:             http://github.com/informatikr/aeson-pretty
synopsis:             JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.

    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.

    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this

    > cabal install -flib-only aeson-pretty

    the command-line tool will NOT be installed.

category:             Text, Web, JSON, Pretty Printer
abi:                  7ff75fffa10a5a5f5737f8425391726d
exposed:              True
exposed-modules:      Data.Aeson.Encode.Pretty
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-pretty-0.8.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-pretty-0.8.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-pretty-0.8.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-pretty
hs-libraries:         HSaeson-pretty-0.8.10-HGqdLPRnyeEEY0lM8KqhKG
depends:
    aeson-2.1.2.1-AErwMfn2r5g1Pc6FekWoJb base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz bytestring-0.11.5.3
    scientific-0.3.8.0-Hcx0Ig8vfV6K9QIlykOJmr text-2.0.2
    unordered-containers-0.2.20-2t1vPVJZrFoJrApu3o7oBM
    vector-0.13.2.0-ALyKXv7XVpOIl9EVBdgwIc

haddock-interfaces:
    /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock

haddock-html:         /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-pretty-0.8.10-135-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-pretty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-pretty
version:              0.8.10
visibility:           public
id:                   aeson-pretty-0.8.10-BWBr3n5fp9E4XyIlTfMbVH
key:                  aeson-pretty-0.8.10-BWBr3n5fp9E4XyIlTfMbVH
license:              BSD-3-Clause
copyright:            Copyright 2011 Falko Peters
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Falko Peters <falko.peters@gmail.com>
stability:            experimental
homepage:             http://github.com/informatikr/aeson-pretty
synopsis:             JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readabilty of streams of JSON data.

    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.

    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing. If you specify @-flib-only@ like this

    > cabal install -flib-only aeson-pretty

    the command-line tool will NOT be installed.

category:             Text, Web, JSON, Pretty Printer
abi:                  1f9175cffb39a3939a0e3edb112ba86c
exposed:              True
exposed-modules:      Data.Aeson.Encode.Pretty
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-pretty-0.8.10
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-pretty-0.8.10
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-pretty-0.8.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-pretty
hs-libraries:         HSaeson-pretty-0.8.10-BWBr3n5fp9E4XyIlTfMbVH
depends:
    aeson-2.1.2.1-6h5MFvBT17H5yplsTy4ABm base-4.17.2.1
    base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz bytestring-0.11.5.3
    scientific-0.3.8.0-3KgWCwEWnxjIUGX8ssH1BR text-2.0.2
    unordered-containers-0.2.20-2N1fR83O3bC5qS2nrjaL2B
    vector-0.13.2.0-EQFZws9ZIK8A2ESM3MR23n

haddock-interfaces:
    /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock

haddock-html:         /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
